@@ -363,7 +363,7 @@ atr <- function(x, levs){
       colnames(mm) <- rownames(mm) <- colnames(dummy)
     }
   }
-  return(list(dummy,mm))
+  return(list(Z=dummy,thetaC=mm))
 }
 csr <- function(x,mm){
   if(is.matrix(x)){
@@ -388,7 +388,7 @@ csr <- function(x,mm){
   }
   # mm[lower.tri(mm)] <- 0
   colnames(mm) <- rownames(mm) <- colnames(dummy)
-  return(list(dummy,mm))
+  return(list(Z=dummy,thetaC=mm))
 }
 dsr <- function(x){
   if(is.matrix(x)){
@@ -414,7 +414,7 @@ dsr <- function(x){
     }
   }
   colnames(mm) <- rownames(mm) <- colnames(dummy)
-  return(list(dummy,mm))
+  return(list(Z=dummy,thetaC=mm))
 }
 usr <- function(x){
   # namx <- as.character(substitute(list(x)))[-1L]
@@ -440,7 +440,7 @@ usr <- function(x){
     mm <- unsm(ncol(dummy))
   }
   colnames(mm) <- rownames(mm) <- colnames(dummy) 
-  return(list(dummy,mm))
+  return(list(Z=dummy,thetaC=mm))
 }
 
 ###############
@@ -535,7 +535,7 @@ dsc <- function(x, thetaC=NULL, theta=NULL){
   }else{
     if(!is.character(x) & !is.factor(x)){
       namess <- as.character(substitute(list(x)))[-1L]
-      dummy <- as(Matrix(x,ncol=1), Class = "sparseMatrix"); colnames(dummy) <- namess
+      dummy <- as(Matrix(x,ncol=1), Class = "dgCMatrix"); colnames(dummy) <- namess
       mm <- diag(ncol(dummy)); 
     }else{
       dummy <- x
@@ -605,7 +605,7 @@ usc <- function(x, thetaC=NULL, theta=NULL){
 }
 isc <- function(x, thetaC=NULL, theta=NULL){
   if(class(x)[1] %in% c("dgCMatrix","matrix") ){
-    dummy <- as(x, Class="sparseMatrix")
+    dummy <- as(x, Class="dgCMatrix")
     mm <- diag(1)#,ncol(x))
   }else{ # if user provides a vector
     if(!is.character(x) & !is.factor(x)){
